@@ -18,7 +18,7 @@ class MC(Cog):
         threading.Thread(target=self.bot.loop.call_soon_threadsafe, args=[self.bot.message_queue]).start()
 
     @command(name='mc')
-    def mc(self, ctx, cmd, *params):
+    async def mc(self, ctx, cmd, *params):
         self.bot.server.run_cmd('execute', 'as', ctx.author.nick, 'run', cmd, *params)
 
     async def message_worker(self):
